@@ -8,6 +8,7 @@ from manufacturing.visual import (
     control_chart_base,
     control_plot,
     cpk_plot,
+    np_chart,
     p_chart,
     ppk_plot,
     x_mr_chart,
@@ -25,6 +26,7 @@ __all__ = [
     "generate_production_report",
     "import_csv",
     "import_excel",
+    "np_chart",
     "p_chart",
     "ppk_plot",
     "suggest_specification_limits",
