@@ -25,4 +25,21 @@ def coerce(data: (List[int], List[float], pd.Series, np.array)) -> pd.Series:
             "floats, a pandas.Series, or numpy.array"
         )
 
-    return data.reset_index(drop=True)
+    return data
+
+
+def remove_outliers(data: pd.Series) -> "pd.Series":
+    # when data is considered an extreme outlier,
+    # then we will re-scale the y limits
+    data = data.copy().dropna()
+
+    q25 = data.quantile(0.25)
+    q50 = data.quantile(0.50)
+    q75 = data.quantile(0.75)
+    iqr = (q75 - q25) * 2
+    min_data = q50 - (iqr * 1.5)
+    max_data = q50 + (iqr * 1.5)
+
+    data = data[(data > min_data) & (data < max_data)]
+
+    return data.dropna().reset_index(drop=True)
